/* firesokker-economy.js
 *
 * Generate a summary of the last two weeks and create a new table
 *
 * @author Christian Graffer
 */

/* Function: fsok_addEconomyTable
 *
 * Add a two week balance to the economy page
 *
 * @param obj   doc         the document node
 *
 * @return void
 */
function fsok_addEconomyTable(doc) {
	if (fsok_prefs.getBoolPref("economy_table")) {
		addStyleSheets(doc);
		createNewTable(doc);
	}

    /* Function: createNewTable
     *
     * Read the table data and create a new table
     *
     * @param obj   doc         the document node
     *
     * @return void
     */
	function createNewTable(doc) {
		var tables = doc.getElementsByTagName('table');
		var this_week_table = tables[0];
		var last_week_table = tables[1];

		var this_week_tds = this_week_table.getElementsByTagName('td');
		var last_week_tds = last_week_table.getElementsByTagName('td');

		var currency_symbol = doc.getElementsByTagName('span')[0].innerHTML.replace(/.*\d/g,'').trim();
		var texts = new Array();
		texts['income'] = this_week_tds[0].innerHTML;
		texts['income_sponsors'] = this_week_tds[6].innerHTML;
		texts['income_transfers'] = this_week_tds[11].innerHTML;
		texts['income_tickets'] = this_week_tds[16].innerHTML;
		texts['income_other'] = this_week_tds[21].innerHTML;
		texts['income_total'] = this_week_tds[36].getElementsByTagName('strong')[0].innerHTML;
		texts['expenses'] = this_week_tds[3].innerHTML;
		texts['expenses_transfers'] = this_week_tds[14].innerHTML;
		texts['expenses_stadium'] = this_week_tds[19].innerHTML;
		texts['expenses_other'] = this_week_tds[24].innerHTML;
		texts['expenses_salaries'] = this_week_tds[29].innerHTML;
		texts['expenses_juniors'] = this_week_tds[34].innerHTML;
		texts['expenses_total'] = this_week_tds[39].getElementsByTagName('strong')[0].innerHTML;
		texts['final'] = this_week_tds[41].getElementsByTagName('strong')[0].innerHTML;

		// LOTS of calculations
		var this_week_income = new Array();
		this_week_income['sponsors'] = this_week_tds[7].innerHTML.replace(/\D/g,"");
		this_week_income['transfers'] = this_week_tds[12].innerHTML.replace(/\D/g,"");
		this_week_income['tickets'] = this_week_tds[17].innerHTML.replace(/\D/g,"");
		this_week_income['other'] = this_week_tds[22].innerHTML.replace(/\D/g,"");
		this_week_income['sum'] = eval(this_week_income['sponsors']+'+'+
									   this_week_income['transfers']+'+'+
									   this_week_income['tickets']+'+'+
									   this_week_income['other']);

		var last_week_income = new Array();
		last_week_income['sponsors'] = last_week_tds[7].innerHTML.replace(/\D/g,"");
		last_week_income['transfers'] = last_week_tds[12].innerHTML.replace(/\D/g,"");
		last_week_income['tickets'] = last_week_tds[17].innerHTML.replace(/\D/g,"");
		last_week_income['other'] = last_week_tds[22].innerHTML.replace(/\D/g,"");
		last_week_income['sum'] = eval(last_week_income['sponsors']+'+'+
									   last_week_income['transfers']+'+'+
									   last_week_income['tickets']+'+'+
									   last_week_income['other']);

		var this_week_expenses = new Array();
		this_week_expenses['transfers'] = this_week_tds[15].innerHTML.replace(/\D/g,"");
		this_week_expenses['stadium'] = this_week_tds[20].innerHTML.replace(/\D/g,"");
		this_week_expenses['other'] = this_week_tds[25].innerHTML.replace(/\D/g,"");
		this_week_expenses['salaries'] = this_week_tds[30].innerHTML.replace(/\D/g,"");
		this_week_expenses['juniors'] = this_week_tds[35].innerHTML.replace(/\D/g,"");
		this_week_expenses['sum'] = eval(this_week_expenses['salaries']+'+'+
										 this_week_expenses['transfers']+'+'+
										 this_week_expenses['stadium']+'+'+
										 this_week_expenses['other']+'+'+
										 this_week_expenses['juniors']);

		var last_week_expenses = new Array();
		last_week_expenses['transfers'] = last_week_tds[15].innerHTML.replace(/\D/g,"");
		last_week_expenses['stadium'] = last_week_tds[20].innerHTML.replace(/\D/g,"");
		last_week_expenses['other'] = last_week_tds[25].innerHTML.replace(/\D/g,"");
		last_week_expenses['salaries'] = last_week_tds[30].innerHTML.replace(/\D/g,"");
		last_week_expenses['juniors'] = last_week_tds[35].innerHTML.replace(/\D/g,"");
		last_week_expenses['sum'] = eval(last_week_expenses['salaries']+'+'+
										 last_week_expenses['transfers']+'+'+
										 last_week_expenses['stadium']+'+'+
										 last_week_expenses['juniors']+'+'+
										 last_week_expenses['other']);

		var diff_week_income = new Array();
		diff_week_income['sponsors'] = eval(this_week_income['sponsors']+'-'+last_week_income['sponsors']);
		diff_week_income['transfers'] = eval(this_week_income['transfers']+'-'+last_week_income['transfers']);
		diff_week_income['tickets'] = eval(this_week_income['tickets']+'-'+last_week_income['tickets']);
		diff_week_income['other'] = eval(this_week_income['other']+'-'+last_week_income['other']);
		diff_week_income['sum'] = this_week_income['sum']-last_week_income['sum'];

		var sum_week_income = new Array();
		sum_week_income['sponsors'] = eval(this_week_income['sponsors']+'+'+last_week_income['sponsors']);
		sum_week_income['transfers'] = eval(this_week_income['transfers']+'+'+last_week_income['transfers']);
		sum_week_income['tickets'] = eval(this_week_income['tickets']+'+'+last_week_income['tickets']);
		sum_week_income['other'] = eval(this_week_income['other']+'+'+last_week_income['other']);
		sum_week_income['sum'] = this_week_income['sum']+last_week_income['sum'];

		var diff_week_expenses = new Array();
		diff_week_expenses['stadium'] = eval(this_week_expenses['stadium']+'-'+last_week_expenses['stadium']);
		diff_week_expenses['transfers'] = eval(this_week_expenses['transfers']+'-'+last_week_expenses['transfers']);
		diff_week_expenses['salaries'] = eval(this_week_expenses['salaries']+'-'+last_week_expenses['salaries']);
		diff_week_expenses['other'] = eval(this_week_expenses['other']+'-'+last_week_expenses['other']);
		diff_week_expenses['juniors'] = eval(this_week_expenses['juniors']+'-'+last_week_expenses['juniors']);
		diff_week_expenses['sum'] = this_week_expenses['sum']-last_week_expenses['sum'];

		var sum_week_expenses = new Array();
		sum_week_expenses['stadium'] = eval(this_week_expenses['stadium']+'+'+last_week_expenses['stadium']);
		sum_week_expenses['transfers'] = eval(this_week_expenses['transfers']+'+'+last_week_expenses['transfers']);
		sum_week_expenses['salaries'] = eval(this_week_expenses['salaries']+'+'+last_week_expenses['salaries']);
		sum_week_expenses['other'] = eval(this_week_expenses['other']+'+'+last_week_expenses['other']);
		sum_week_expenses['juniors'] = eval(this_week_expenses['juniors']+'+'+last_week_expenses['juniors']);
		sum_week_expenses['sum'] = this_week_expenses['sum']+last_week_expenses['sum'];

		var total_sum = sum_week_income['sum']-sum_week_expenses['sum'];
		var spanstart = '';
		var spanend = '';
		if (total_sum > 0) {
			spanstart = '<span class="fsok_positive_diff">';
			spanend = '</span>';
		} else {
			if (total_sum < 0) {
				spanstart = '<span class="fsok_negative_diff">';
				spanend = '</span>';
			}
		}

		var new_diff_week_income = new Array();
		var new_sum_week_income = new Array();
		var new_diff_week_expenses = new Array();
		var new_sum_week_expenses = new Array();
		for (var temp in diff_week_income) {
			new_diff_week_income[temp] = formatNumber(diff_week_income[temp],0,' ','','','','','');
		}

		for (var temp in sum_week_income) {
			new_sum_week_income[temp] = formatNumber(sum_week_income[temp],0,' ','','','','','');
		}

		for (var temp in diff_week_expenses) {
			new_diff_week_expenses[temp] = formatNumber(diff_week_expenses[temp],0,' ','','','','','');
		}

		for (var temp in sum_week_expenses) {
			new_sum_week_expenses[temp] = formatNumber(sum_week_expenses[temp],0,' ','','','','','');
		}

		// build the table rows
		var sponsors = '<tr><td style="width:25%;">'+texts['income_sponsors']+'</td>'+
			'<td style="width: 15%;" align="right"><span class="'+(diff_week_income['sponsors'] < 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">') +
			new_diff_week_income['sponsors']+'</span> '+currency_symbol+'<br/>'+new_sum_week_income['sponsors']+' '+currency_symbol+'</td>'+
 			'<td style="width: 3%;"></td><td style="width:25%;"></td><td style="width: 15%;" align="right"></td></tr>';
		var transfers = '<tr><td style="width:25%;">'+texts['income_transfers']+'</td>'+
			'<td style="width: 15%;" align="right"><span class="'+(diff_week_income['transfers'] < 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">') +
			new_diff_week_income['transfers']+'</span> '+currency_symbol+'<br/>'+new_sum_week_income['transfers']+' '+currency_symbol+'</td>'+
			'<td style="width: 3%;"></td><td style="width:25%;">'+texts['expenses_transfers']+'</td>'+
			'<td style="width: 15%;" align="right"><span class="'+(diff_week_expenses['transfers'] >= 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">-') +
			new_diff_week_expenses['transfers']+'</span> '+currency_symbol+'<br/>'+new_sum_week_expenses['transfers']+' '+currency_symbol+'</td>';
		var tickets = '<tr><td style="width:25%;">'+texts['income_tickets']+'</td>'+
			'<td style="width: 15%;" align="right"><span class="'+(diff_week_income['tickets'] < 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">') +
			new_diff_week_income['tickets']+'</span> '+currency_symbol+'<br/>'+new_sum_week_income['tickets']+' '+currency_symbol+'</td>'+
			'<td style="width: 3%;"></td><td style="width:25%;">'+texts['expenses_stadium']+'</td>'+
			'<td style="width: 15%;" align="right"><span class="'+(diff_week_expenses['stadium'] >= 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">-') +
			new_diff_week_expenses['stadium']+'</span> '+currency_symbol+'<br/>'+new_sum_week_expenses['stadium']+' '+currency_symbol+'</td>';
		var other = '<tr><td style="width:25%;">'+texts['income_other']+'</td>'+
			'<td style="width: 15%;" align="right"><span class="'+(diff_week_income['other'] < 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">') +
			new_diff_week_income['other']+'</span> '+currency_symbol+'<br/>'+new_sum_week_income['other']+' '+currency_symbol+'</td>'+
			'<td style="width: 3%;"></td><td style="width:25%;">'+texts['expenses_other']+'</td>'+
			'<td style="width: 15%;" align="right"><span class="'+(diff_week_expenses['other'] >= 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">-') +
			new_diff_week_expenses['other']+'</span> '+currency_symbol+'<br/>'+new_sum_week_expenses['other']+' '+currency_symbol+'</td>';
		var salaries = '<tr><td style="width:25%;"></td><td style="width: 15%;" align="right"></td><td style="width: 3%;"></td><td style="width:25%;">'+
			texts['expenses_salaries']+'</td>'+
			'<td style="width: 15%;" align="right"><span class="'+(diff_week_expenses['salaries'] >= 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">-') +
			new_diff_week_expenses['salaries']+'</span> '+currency_symbol+'<br/>'+new_sum_week_expenses['salaries']+' '+currency_symbol+'</td>';
		var juniors = '<tr><td style="width:25%;"></td><td style="width: 15%;" align="right"></td><td style="width: 3%;"></td><td style="width:25%;">'+
			texts['expenses_juniors']+'</td>'+
			'<td style="width: 15%;" align="right"><span class="'+(diff_week_expenses['juniors'] >= 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">-') +
			new_diff_week_expenses['juniors']+'</span> '+currency_symbol+'<br/>'+new_sum_week_expenses['juniors']+' '+currency_symbol+'</td>';
		var total = '<tr><td style="width:25%;" class="bgColor1"><strong>'+texts['income_total']+'</strong></td>'+
			'<td style="width: 15%;" align="right" class="bgColor1"><strong><span class="'+(diff_week_income['sum'] < 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">') +
			new_diff_week_income['sum']+'</span> '+currency_symbol+'<br/>'+new_sum_week_income['sum']+' '+currency_symbol+'</strong></td>'+
			'<td style="width: 3%;"></td>'+'<td style="width:25%;" class="bgColor1"><strong>'+texts['expenses_total']+'</strong></td>'+
			'<td style="width: 15%;" align="right" class="bgColor1"><strong><span class="'+(diff_week_expenses['sum'] >= 0 ? 'fsok_negative_diff">' : 'fsok_positive_diff">-') +
			new_diff_week_expenses['sum']+'</span> '+currency_symbol+'<br/>'+new_sum_week_expenses['sum']+' '+currency_symbol+'</strong></td></tr>';
		var summary = '<tr><td style="width:25%;"><b>'+texts['final']+'</b></td><td style="width: 15%;" align="right"><b>'+spanstart+formatNumber(total_sum,0,' ','','','','','')+spanend+' '+currency_symbol+
			'</b><td style="width: 3%;"></td><td style="width:25%;"></td><td style="width: 15%;" align="right"></td></tr>';

		var tab = doc.createElement('div');
		tab.className = 'container';

		var new_div_1 = doc.createElement('div');
		new_div_1.className = 'topLeft';
		new_div_1.innerHTML = '<div class="topRight"></div>';

		var new_div_2 = doc.createElement('div');
		new_div_2.className = 'leftLine';
		var new_div_2_1 = doc.createElement('div');
		new_div_2_1.className = 'rightLine';
		new_div_2.appendChild(new_div_2_1);
		var new_div_2_1_a = doc.createElement('div');
		new_div_2_1_a.className = 'header';
		new_div_2_1_a.innerHTML = '<div class="titleBlock1">'+fsok_language.biweekly_balance+':</div>';
		new_div_2_1.appendChild(new_div_2_1_a);
		var new_div_2_1_b = doc.createElement('div');
		new_div_2_1_b.className = 'insideContainer space2Top';
		new_div_2_1.appendChild(new_div_2_1_b);
		var new_div_2_1_b_1 = doc.createElement('div');
		new_div_2_1_b_1.className = 'insideTopLeft';
		new_div_2_1_b_1.innerHTML = '<div class="insideTopRight"></div>';
		var new_div_2_1_b_2 = doc.createElement('div');
		new_div_2_1_b_2.className = 'content';
		new_div_2_1_b.appendChild(new_div_2_1_b_1);
		new_div_2_1_b.appendChild(new_div_2_1_b_2);

		var new_div_3 = doc.createElement('div');
		new_div_3.className = 'bottomLeft';
		new_div_3.innerHTML = '<div class="bottomRight"></div>';

		var table_summary = doc.createElement('table');
		table_summary.innerHTML = '<tbody>'+
			'<tr><td style="width:25%;"><u>'+texts['income']+'</u></td><td style="width: 15%;" align="right"></td><td style="width: 3%;"></td><td style="width:25%;"><u>'+texts['expenses']+'</u></td><td style="width: 15%;" align="right"></td></tr>'+
			sponsors + transfers + tickets + other + salaries + juniors + total + summary;
		new_div_2_1_b_2.appendChild(table_summary);

		tab.appendChild(new_div_1);
		tab.appendChild(new_div_2);
		tab.appendChild(new_div_3);
		doc.getElementsByTagName('div')[9].appendChild(doc.createElement('br'));
		doc.getElementsByTagName('div')[9].appendChild(tab);

	}

    /* Function: addStyleSheets
     *
     * Add stylesheets to the page header
     *
     * @param obj   doc         the document node
     *
     * @return void
     */
	function addStyleSheets(doc) {
        head = doc.getElementsByTagName('head')[0];
        if (!head) { return; }
        style = doc.createElement("style");
        style.type = "text/css";
        style.innerHTML = ".fsok_negative_diff {color:red;} .fsok_positive_diff {color:green;}";
		head.appendChild(style);
	}
}

if (!fsok_functions["/economy.php"])
	fsok_functions["/economy.php"] = new Array();
fsok_functions["/economy.php"][fsok_functions["/economy.php"].length] = fsok_addEconomyTable;
