/* firesokker-lineup.js
 * 
 * Lineup information
 *
 * @author Christian Graffer
 */

/* Function: fsok_addLineupHandlers
 *
 * This function adds onchange handlers to all the position dropdowns
 *
 * @param obj   doc         the document node
 *
 * @return void
 */

function fsok_addLineupHandlers(doc) {
	var selects = doc.getElementsByTagName('select');
	for (var i = 0; i < selects.length; i++) {
		if (selects[i] != null && selects[i].getAttribute('name') != null) {
			var name = selects[i].getAttribute('name');
			if (name.substr(0,5) == 'Order') {
				selects[i].addEventListener('click',fsok_showLineup,false);
				selects[i].addEventListener('change',fsok_showLineup,false);
			}
		}
	}
}


/* Function: fsok_createLineupDiv
 *
 * This function adds the DIV element to which the lineup information will be written
 *
 * @param obj   doc         the document node
 *
 * @return void
 */

function fsok_createLineupDiv(doc) {
	var myobject = doc.getElementsByTagName('object')[0];
	var newdiv = doc.createElement('div');
	newdiv.setAttribute('id','fsok_lineup_div');
	newdiv.className = 'bgColor1';
	newdiv.style.width = '100%';
	newdiv.style.fontWeight = 'bold';
	newdiv.style.textAlign = 'center';
	newdiv.style.fontSize = '9pt';
	myobject.parentNode.appendChild(doc.createElement('br'));
	myobject.parentNode.appendChild(newdiv);
}

/* Function: fsok_showLineup
 *
 * This function calculates team-statistics
 *
 * @param obj   doc         the document node
 *
 * @return void
 */

function fsok_showLineup(doc) {
	if (doc.nodeType == null) {
		doc = doc.originalTarget.ownerDocument;
	}
	if (fsok_prefs.getBoolPref("match_statistics") && lineup_link.test(doc.location.search)) {
		var lineup = fsok_parseLineup();
		if (doc.getElementById('fsok_lineup_div') == null)
			fsok_createLineupDiv(doc);
		doc.getElementById('fsok_lineup_div').innerHTML = fsok_language.formation+ ': ' + lineup.presentation;
    }

    /* Function: fsok_parseLineup
     *
     * This function calculates the lineup
     *
     * @param obj   doc         the document node
     *
     * @return object lineup
     */
	function fsok_parseLineup() {
		var lineup = new Object;
		lineup.presentation = '';
		lineup.keepers = 0;
		lineup.defenders = 0;
		lineup.midfielders = 0;
		lineup.attackers = 0;
		lineup.s_keepers = 0;
		lineup.s_defenders = 0;
		lineup.s_midfielders = 0;
		lineup.s_attackers = 0;
		var selects = doc.getElementsByTagName('select');
		for (var i = 1; i <= 16; i++) {
			if (i == 1 || i == 12)
				continue;
			for (var j = 0; j < selects.length; j++) {
				var y = selects[j];
				if (y != null && y.getAttribute('name') == "Order"+i) {
					if (i <= 11) {
						if (y.value == '1')
							lineup.defenders += 1;
						else if (y.value == '2')
							lineup.midfielders += 1;
						else if (y.value == '3')
 							lineup.attackers += 1;
					} else {
						if (y.value == '1')
							lineup.s_defenders += 1;
						else if (y.value == '2')
							lineup.s_midfielders += 1;
						else if (y.value == '3')
							lineup.s_attackers += 1;
					}
					continue;
				}
			}
		}
		lineup.presentation = '<span style="color:' + (lineup.defenders > 5 ? 'red' : 'black')+ '">'+lineup.defenders+'</span>-';
		lineup.presentation += '<span style="color:' + (lineup.midfielders > 5 ? 'red' : 'black')+ '">'+lineup.midfielders+'</span>-';
		lineup.presentation += '<span style="color:' + (lineup.attackers > 3 ? 'red' : 'black')+ '">'+lineup.attackers+'</span>';
		return lineup;
	}
}

if (!fsok_functions["/lineup.php"])
	fsok_functions["/lineup.php"] = new Array();

fsok_functions["/lineup.php"][fsok_functions["/lineup.php"].length] = fsok_addLineupHandlers;
fsok_functions["/lineup.php"][fsok_functions["/lineup.php"].length] = fsok_showLineup;
