/* firesokker-matches.js
 * 
 * Match details and summaries
 *
 * @author Christian Graffer
 */

/* Function: fsok_showMatchStats
 *
 * This function calculates team-statistics
 *
 * @param obj   doc         the document node
 *
 * @return void
 */

function fsok_showMatchStats(doc) {
	if (fsok_prefs.getBoolPref("match_statistics")) {
		var statistics = fsok_parseMatchStats();
		var tab = doc.createElement('table');
		tab.className = 'tableStyle3 bgColor1';
		var tab_content = '<tbody>';
		tab.style.width = '340px';
		tab.style.height = '78px';
		tab.style.fontSize = '7pt';
		tab.style.fontFamily = 'Verdana,Helvetica,Arial,sans-serif';
		tab.style.border = 'none';
		tab.style.paddingTop = '2px';
		tab.style.paddingBottom = '1px';
		tab.style.verticalAlign = 'top';
		tab_content += '<tr class="bgColor4 textColor6"><td><b>'+fsok_language.formation+':</b></td><td align="right">'+statistics.defenders+'-'+statistics.midfielders+'-'+statistics.attackers+'</td><td width="10px">&nbsp;</td>'+
		               '<td><b>'+fsok_language.substitutions+':</b></td><td align="right">'+statistics.substitutions+'</td></tr>';
		tab_content += '<tr class="bgColor5 textColor6"><td><b>'+fsok_language.shots+':</b></td><td align="right">'+statistics.shots+'</td><td width="10px">&nbsp;</td><td><b>'+fsok_language.fouls+':</b></td><td align="right">'+statistics.fouls+'</td></tr>';
		tab_content += '<tr class="bgColor4 textColor6"><td><b>'+fsok_language.goals+':</b></td><td align="right"><img src="'+img_goal+'"> '+statistics.goals+'</td><td width="10px">&nbsp;'+
			           '</td><td><b>'+fsok_language.assists+':</b></td><td align="right"<img src="'+img_assist+'"> '+statistics.assists+'</td></tr>';
		tab_content += '<tr class="bgColor5 textColor6"><td><b>'+fsok_language.avg_vote+':</b></td><td align="right">'+statistics.votes+'</td><td width="10px">&nbsp;</td><td colspan="2" align="center">'+
			                (statistics.red > 0 ? '<img src="'+img_rcard+'"> ('+statistics.red+') ' : '') + 
			                (statistics.yellow > 0 ? '<img src="'+img_ycard+'"> ('+statistics.yellow+') ' : '')+
			                (statistics.injuries > 0 ? '<img src="'+img_injury+'"> ('+statistics.injuries+') ' : '')+
			'</td></tr>';
		tab_content += '</tbody>';
		tab.innerHTML = tab_content;
		doc.getElementsByTagName('object')[0].parentNode.appendChild(tab);
	}

    /* Function: fsok_showMatchStats
     *
     * This function calculates team-statistics
     *
     * @param obj   doc         the document node
     *
     * @return void
     */
	function fsok_parseMatchStats() {
		var statistics = new Object;
		statistics.injuries = 0;
		statistics.yellow = 0;
		statistics.red = 0;
		statistics.substitutions = 0;
		statistics.defenders = 0;
		statistics.midfielders = 0;
		statistics.attackers = 0;
		statistics.votes = 0;
		statistics.shots = 0;
		statistics.fouls = 0;
		statistics.assists = 0;
		statistics.goals = 0;
		var table = doc.getElementsByTagName('table')[1];
		var trs = table.getElementsByTagName('tr');
		for (var i=1;i < trs.length;i++) {
			var tds = trs[i].getElementsByTagName('td');
			var is_substitute = false;
			var number = 0;
			// player header
			if (tds.length == 2) {
				if (tds[0].innerHTML.replace(/\D*/g,'') == '') {
					statistics.substitutions += 1;
					is_substitute = true;
				} else {
					number = tds[0].innerHTML.replace(/\D*/g,'');
				}
				var imgs = tds[1].getElementsByTagName('img');
				for (var j=0; j < imgs.length; j++) {
					switch (imgs[j].src) {
					case img_ycard:
						statistics.yellow += 1;
						break;
					case img_rcard:
						statistics.red += 1;
						break;
					case img_goal:
						statistics.goals += 1;
						break;
					case img_assist:
						statistics.assists += 1;
						break;
					case img_injury:
						statistics.injuries += 1;
					}
				}
				if (!is_substitute && parseInt(number) <= 11) {
					var position = fsok_getTextOnly(tds[1]).trim();
					position = position.split(" ");
					position = position[position.length - 1];
					switch (position.trim()) {
					case 'DEF':
						statistics.defenders += 1;
						break;
					case 'MID':
						statistics.midfielders += 1;
						break;
					case 'ATT':
						statistics.attackers += 1;
						break;
					}
				}
			} else { // end of player header
				var vote = parseInt(tds[1].getElementsByTagName('strong')[0].innerHTML);
				if (vote > 0) {
					statistics.votes += vote;
				}
				if (tds[3].innerHTML.trim() != '&nbsp;' && tds[3].innerHTML.trim() != "") {
					statistics.shots += parseInt(tds[3].innerHTML.trim());
				}
				if (tds[4].innerHTML.trim() != '&nbsp;' && tds[4].innerHTML.trim() != "") {
					statistics.fouls += parseInt(tds[4].innerHTML.trim());
				}
			}
		}
		statistics.votes = formatNumber(statistics.votes/(11+statistics.substitutions),2,'','.','','','','');
		return statistics;
	}
}

if (!fsok_functions["/stats.php"])
	fsok_functions["/stats.php"] = new Array();

fsok_functions["/stats.php"][fsok_functions["/stats.php"].length] = fsok_showMatchStats;
