/* firesokker-teamlinks.js
 *
 * This file takes care of displaying additional links for each
 * team when moving the mousecursor over a team link.
 *
 * @author Christian Graffer
 */

/* Function: fsok_modifyTeamLinks
 *
 * Search for the Team Links and wrap a span around them,
 * which also includes a div with the new links
 *
 * @param obj   doc         the document node
 *
 * @return void
 */
function fsok_modifyTeamLinks(doc) {
	if (fsok_prefs.getBoolPref("show_team_links")) {
		fsok_addStyleSheets(doc);
		var links = doc.getElementsByTagName('a');
		for (var i = 0; i < links.length; i++) {
			var link = links[i].href;
			link = link.split('/');
			if (link.length > 1 && link[link.length - 1].substr(0,18) == team_links_start_string && !link[link.length -1].match(/showpress/)) {
				var team_id = link[link.length - 1].split("=")[1];
				var links_div = fsok_buildHiddenDiv(doc,team_id);
				var nspan = doc.createElement("span");
				nspan.setAttribute("class","teamlink_span");
				links[i].parentNode.insertBefore(nspan,links[i]);
				nspan.appendChild(links[i]);
				nspan.appendChild(links_div);
			}
		}
	}

	/* Function: fsok_buildHiddenDiv
     *
     * Build a hidden div element with lots of CSS information.
     * This function returns the created node.
     *
     * @param obj   doc         the document node
     * @param int   team_id     the ID of the team
     *
     * @return node div_node    the DOM-node of the div
     */
	function fsok_buildHiddenDiv(doc,team_id) {
		var links_div = doc.createElement("div");
		var inner_html_string = "<a class='linkStyle1' href='matches.php?teamID="+team_id+"'>"+fsok_language.matches+"</a><br />"+
            "<a class='linkStyle1' href='players.php?teamID="+team_id+"'>"+fsok_language.players+"</a><br />";
		if (doc.location.pathname != "/ntrank.php" && !fsok_isNationalTeam(team_id)) {
			inner_html_string += "<a class='linkStyle1' href='transfers_team.php?teamID="+team_id+"'>"+fsok_language.transfers+"</a><br />";
			links_div.setAttribute("class","hidden_div");
		} else {
			links_div.setAttribute("class","hidden_nt_div");
		}
		inner_html_string += "<a class='linkStyle1' href='history_team.php?teamID="+team_id+"'>"+fsok_language.history+"</a>";

		links_div.innerHTML = inner_html_string;
		return links_div;
	}


    /* Function: fsok_addStyleSheets
     *
     * Add stylesheets to the page header
     *
     * @param obj   doc         the document node
     *
     * @return void
     */
    function fsok_addStyleSheets(doc) {
        var head = doc.getElementsByTagName('head')[0];
        if (!head) { return; }
        var style = doc.createElement("style");
        style.type = "text/css";
        style.innerHTML = "div.hidden_div {display:none; visibility: hidden;} "+
                          "div.hidden_nt_div {display:none; visibility: hidden;} "+
                          "span.teamlink_span {position: relative;} "+
                          "span.teamlink_span:hover div.hidden_div {"+
                          "  background-color: #FFFFFF;"+
                          "  border: solid 1px #000000;"+
                          "  display: block;"+
                          "  visibility: visible;"+
                          "  position: absolute;"+
                          "  left: 30px;"+
                          "  top: -60px;"+
                          "  padding: 2px;"+
                          "  width: 85px;"+
                          "  text-align: left;"+
                          "  font-weight: normal;"+
                          "}"+
                          "span.teamlink_span:hover div.hidden_div a {"+
						  "  color: #000 !important;"+
						  "}"+
                          "span.teamlink_span:hover div.hidden_div a:hover {"+
						  "  color: #444 !important;"+
						  "}"+
						  "span.teamlink_span:hover div.hidden_nt_div {"+
                          "  background-color: #FFFFFF;"+
                          "  border: solid 1px #000000;"+
                          "  display: block;"+
                          "  visibility: visible;"+
                          "  position: absolute;"+
                          "  left: 30px;"+
                          "  top: -42px;"+
                          "  padding: 2px;"+
                          "  width: 85px;"+
                          "  text-align: left;"+
                          "  font-weight: normal;"+
                          "}"+
                          "span.teamlink_span:hover div.hidden_nt_div a {"+
						  "  color: #000 !important;"+
						  "}"+
                          "span.teamlink_span:hover div.hidden_nt_div a:hover {"+
						  "  color: #444 !important;"+
		"}";
        head.appendChild(style);
    }

}

fsok_global_functions[fsok_global_functions.length] = fsok_modifyTeamLinks;